@@ -1,5 +1,5 @@
 package WebService::Blogger;
-$WebService::Blogger::VERSION = '0.21';
+our $VERSION = '0.22';
 use warnings;
 use strict;
 
@@ -13,7 +13,6 @@ use Encode ();
 
 use WebService::Blogger::Blog;
 
-
 # Authentication credentials. Cannot be changed after object is created.
 has login_id        => ( is => 'ro', isa => 'Str');
 has password        => ( is => 'ro', isa => 'Str');
@@ -73,17 +72,37 @@ sub BUILDARGS {
 
 sub BUILD {
     ## Authenticates with Blogger.
-    my $self = shift;
+    my ($self,$creds) = @_;
 
-    # Submit request fore authentiaction token.
-    my $response = $self->ua->post(
-        'https://www.google.co.uk/accounts/ClientLogin',
-        {
-            Email       => $self->login_id,
-            Passwd      => $self->password,
-            service     => 'blogger',
-        }
-    );
+    # Submit request for authentiaction token.
+    my $response = $self->{'ua'}->post('https://accounts.google.com/o/oauth2/auth',
+          { basic_authentication => $self->{'base64'},
+        	Content_Type         => 'application/x-www-form-urlencoded',
+        	grant_type           => 'client_credentials', 
+        	client_id            => $self->{'key'},
+        	client_secret        => $self->{'secret'},
+          }
+        );
+
+print Dumper($response);
+exit(0);
+
+#There are 4 grant types defined in the OAuth spec.
+#	Authorization code
+#	Implicit
+#	Resource owner password credentials
+#	Client credentials
+
+
+
+
+#    my $response = $self->ua->post('https://www.google.co.uk/accounts/ClientLogin',
+#        {
+#            Email       => $self->login_id,
+#            Passwd      => $self->password,
+#            service     => 'blogger',
+#        }
+#    );
 
     # Check success, parsing Google error message, if available.
     unless ($response->is_success) {
@@ -173,16 +192,19 @@ __END__
 
 =head1 NAME
 
-WebService::Blogger - (DEPRECATED) Interface to Google's Blogger service
+WebService::Blogger - Interface to Google's Blogger service
+
+#############################################################################
+This module is currently under modifications by a new author in order
+to support Google's new authentication method.
+
+Standby for updates
+#############################################################################
 
 =cut
 
 =head1 SYNOPSIS
 
-THIS MODULE IS DEPRECATED AND NO LONGER WORKS SINCE GOOGLE'S BLOGGER
-AUTHENTICATION MECHANISM HAS CHANGED TO OAUTH. IF YOU ARE INTERESTED
-IN TAKING OWNERSHIP OF THIS MODULE PLEASE GET IN TOUCH WITH THE AUTHOR.
-
 This module provides interface to the Blogger service now run by
 Google. It's built in object-oriented fashion with L<Moose>, which makes
 it easy to use and extend. It also utilizes newer style GData API for
@@ -255,7 +277,7 @@ L<WebService::Blogger::Blog>.
 
 =head1 AUTHOR
 
-Egor Shipovalov, C<< <kogdaugodno at gmail.com> >>
+Kedar Warriner, C<< <kedar at cpan.org> >>
 
 =head1 BUGS
 
@@ -265,14 +287,12 @@ Please report any bugs or feature requests to C<bug-webservice-blogger at rt.cpa
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WebService-Blogger>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc WebService::Blogger
 
-
 You can also look for information at:
 
 =over 4
@@ -295,10 +315,15 @@ L<http://search.cpan.org/dist/WebService-Blogger/>
 
 =back
 
+=head1 ACKNOWLEDGEMENTS
+
+ Many thanks to:
+  - Egor Shipovalov who wrote the original version of this module
+  - Everyone involved with CPAN.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 Egor Shipovalov.
+Copyright 2010 Kedar Warriner.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
