@@ -1,5 +1,5 @@
 package WebService::Blogger::Blog;
-$WebService::Blogger::Blog::VERSION = '0.21';
+our $VERSION = '0.22';
 use warnings;
 use strict;
 
@@ -11,7 +11,6 @@ use WebService::Blogger::Blog::Entry;
 
 with 'WebService::Blogger::AtomReading';
 
-
 # Blog properties, non-updatable.
 has id          => ( is => 'ro', isa => 'Str', required => 1 );
 has numeric_id  => ( is => 'ro', isa => 'Str', required => 1 );
@@ -295,7 +294,7 @@ List of blog entries, lazily populated.
 
 =head1 AUTHOR
 
-Egor Shipovalov, C<< <kogdaugodno at gmail.com> >>
+Kedar Warriner, C<< <kedar at cpan.org> >>
 
 =head1 BUGS
 
@@ -331,9 +330,15 @@ L<http://search.cpan.org/dist/WebService-Blogger/>
 
 =back
 
+=head1 ACKNOWLEDGEMENTS
+
+ Many thanks to:
+  - Egor Shipovalov who wrote the original version of this module
+  - Everyone involved with CPAN.
+
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 Egor Shipovalov.
+Copyright 2010 Kedar Warriner.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
@@ -341,5 +346,5 @@ by the Free Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
 
-
 =cut
+
