@@ -1,5 +1,5 @@
 package WebService::Blogger::Blog::Entry;
-$WebService::Blogger::Blog::Entry::VERSION = '0.21';
+our $VERSION = '0.22';
 use warnings;
 use strict;
 
@@ -8,7 +8,6 @@ use XML::Simple ();
 
 with 'WebService::Blogger::AtomReading';
 
-
 # Properties that can be updated in existing entries.
 has title           => ( is => 'rw', isa => 'Maybe[Str]' );
 has content         => ( is => 'rw', isa => 'Maybe[Str]' );
@@ -272,7 +271,7 @@ Deltes the entry from server and parent blog object.
 
 =head1 AUTHOR
 
-Egor Shipovalov, C<< <kogdaugodno at gmail.com> >>
+Kedar Warriner, C<< <kedar at cpan.org> >>
 
 =head1 BUGS
 
@@ -286,7 +285,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc WebService::Blogger
 
-
 You can also look for information at:
 
 =over 4
@@ -309,9 +307,15 @@ L<http://search.cpan.org/dist/WebService-Blogger/>
 
 =back
 
+=head1 ACKNOWLEDGEMENTS
+
+ Many thanks to:
+  - Egor Shipovalov who wrote the original version of this module
+  - Everyone involved with CPAN.
+
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 Egor Shipovalov.
+Copyright 2010 Kedar Warriner.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
@@ -319,5 +323,5 @@ by the Free Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
 
-
 =cut
+
